package org.andromda.utils;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNull;
import org.junit.Test;

/**
 *
 */
public class JavaTypeConverterTest
{
    /**
     *
     */
    public static final class ExpectedResult
    {
        private final String fromType;
        private final String toType;
        private final String expected;

        /**
         * @param fromType
         * @param toType
         * @param expected
         */
        public ExpectedResult(
            String fromType,
            String toType,
            String expected)
        {
            this.fromType = fromType;
            this.toType = toType;
            this.expected = expected;
        }
    }

    private static final ExpectedResult[] expected =
    {
        new ExpectedResult("java.lang.Character", "java.lang.String", "(sourceVal == null ? null : sourceVal.toString())"),
        new ExpectedResult("java.lang.Integer", "double", "(double)(sourceVal == null ? 0 : sourceVal.intValue())"),
        new ExpectedResult("java.lang.Integer", "double[]", null),
        new ExpectedResult("java.lang.Integer", "float", "(float)(sourceVal == null ? 0 : sourceVal.intValue())"),
        new ExpectedResult("java.lang.Integer", "float[]", null),
        new ExpectedResult("java.lang.Integer", "boolean", "((sourceVal == null ? 0 : sourceVal.intValue()) != 0)"),
        new ExpectedResult("java.lang.Integer", "boolean[]", null),
        new ExpectedResult("java.lang.Integer", "java.lang.Integer", "sourceVal"),
        new ExpectedResult("java.lang.Integer", "java.lang.Integer[]", null),
        new ExpectedResult("java.lang.Integer", "java.lang.Long", "new java.lang.Long((long)(sourceVal == null ? 0 : sourceVal.intValue()))"),
        new ExpectedResult("java.lang.Integer", "java.lang.Long[]", null),
        new ExpectedResult("java.lang.Integer", "java.lang.Double", "new java.lang.Double((double)(sourceVal == null ? 0 : sourceVal.intValue()))"),
        new ExpectedResult("java.lang.Integer", "java.lang.Double[]", null),
        new ExpectedResult("java.lang.Integer", "java.lang.Float", "new java.lang.Float((float)(sourceVal == null ? 0 : sourceVal.intValue()))"),
        new ExpectedResult("java.lang.Integer", "java.lang.Float[]", null),
        new ExpectedResult("java.lang.Integer", "java.lang.Boolean", "new java.lang.Boolean(((sourceVal == null ? 0 : sourceVal.intValue()) != 0))"),
        new ExpectedResult("java.lang.Integer", "java.lang.Boolean[]", null),
        new ExpectedResult("java.lang.Integer", "java.util.Date", null),
        new ExpectedResult("java.lang.Integer", "java.util.Date[]", null),
        new ExpectedResult("java.lang.Integer", "java.sql.Timestamp", null),
        new ExpectedResult("java.lang.Integer", "java.sql.Timestamp[]", null),
        new ExpectedResult("java.lang.Integer", "java.sql.Time", null),
        new ExpectedResult("java.lang.Integer", "java.sql.Time[]", null),
        new ExpectedResult("java.lang.Integer", "java.sql.Date", null),
        new ExpectedResult("java.lang.Integer", "java.sql.Date[]", null),
        new ExpectedResult("java.lang.Integer", "java.lang.String", "(sourceVal == null ? null : sourceVal.toString())"),
        new ExpectedResult("java.lang.Integer", "java.lang.String[]", null),
        new ExpectedResult("java.lang.Integer", "com.example.UserClass1", null),
        new ExpectedResult("java.lang.Integer", "com.example.UserClass1[]", null),
        new ExpectedResult("java.lang.Integer", "com.example.UserClass2", null),
        new ExpectedResult("java.lang.Integer", "com.example.UserClass2[]", null),
        new ExpectedResult("java.lang.Integer", "java.math.BigInteger", "(sourceVal == null ? null : java.math.BigInteger.valueOf((long)sourceVal.intValue()))"),
        new ExpectedResult("java.lang.Integer", "java.math.BigInteger[]", null),
        new ExpectedResult("java.lang.Integer", "java.math.BigDecimal", "(sourceVal == null ? null : java.math.BigDecimal.valueOf((long)sourceVal.intValue()))"),
        new ExpectedResult("java.lang.Integer", "java.math.BigDecimal[]", null),
        new ExpectedResult("java.lang.Integer[]", "int", null),
        new ExpectedResult("java.lang.Integer[]", "int[]", null),
        new ExpectedResult("java.lang.Integer[]", "long", null),
        new ExpectedResult("java.lang.Integer[]", "long[]", null),
        new ExpectedResult("java.lang.Integer[]", "double", null),
        new ExpectedResult("java.lang.Integer[]", "double[]", null),
        new ExpectedResult("java.lang.Integer[]", "float", null),
        new ExpectedResult("java.lang.Integer[]", "float[]", null),
        new ExpectedResult("java.lang.Integer[]", "boolean", null),
        new ExpectedResult("java.lang.Integer[]", "boolean[]", null),
        new ExpectedResult("java.lang.Integer[]", "java.lang.Integer", null),
        new ExpectedResult("java.lang.Integer[]", "java.lang.Integer[]", "sourceVal"),
        new ExpectedResult("java.lang.Integer[]", "java.lang.Long", null),
        new ExpectedResult("java.lang.Integer[]", "java.lang.Long[]", null),
        new ExpectedResult("java.lang.Integer[]", "java.lang.Double", null),
        new ExpectedResult("java.lang.Integer[]", "java.lang.Double[]", null),
        new ExpectedResult("java.lang.Integer[]", "java.lang.Float", null),
        new ExpectedResult("java.lang.Integer[]", "java.lang.Float[]", null),
        new ExpectedResult("java.lang.Integer[]", "java.lang.Boolean", null),
        new ExpectedResult("java.lang.Integer[]", "java.lang.Boolean[]", null),
        new ExpectedResult("java.lang.Integer[]", "java.util.Date", null),
        new ExpectedResult("java.lang.Integer[]", "java.util.Date[]", null),
        new ExpectedResult("java.lang.Integer[]", "java.sql.Timestamp", null),
        new ExpectedResult("java.lang.Integer[]", "java.sql.Timestamp[]", null),
        new ExpectedResult("java.lang.Integer[]", "java.sql.Time", null),
        new ExpectedResult("java.lang.Integer[]", "java.sql.Time[]", null),
        new ExpectedResult("java.lang.Integer[]", "java.sql.Date", null),
        new ExpectedResult("java.lang.Integer[]", "java.sql.Date[]", null),
        new ExpectedResult("java.lang.Integer[]", "java.lang.String", null),
        new ExpectedResult("java.lang.Integer[]", "java.lang.String[]", null),
        new ExpectedResult("java.lang.Integer[]", "com.example.UserClass1", null),
        new ExpectedResult("java.lang.Integer[]", "com.example.UserClass1[]", null),
        new ExpectedResult("java.lang.Integer[]", "com.example.UserClass2", null),
        new ExpectedResult("java.lang.Integer[]", "com.example.UserClass2[]", null),
        new ExpectedResult("java.lang.Integer[]", "java.math.BigInteger", null),
        new ExpectedResult("java.lang.Integer[]", "java.math.BigInteger[]", null),
        new ExpectedResult("java.lang.Integer[]", "java.math.BigDecimal", null),
        new ExpectedResult("java.lang.Integer[]", "java.math.BigDecimal[]", null),
        new ExpectedResult("java.lang.Long", "int", "(int)(sourceVal == null ? 0 : sourceVal.longValue())"),
        new ExpectedResult("java.lang.Long", "int[]", null),
        new ExpectedResult("java.lang.Long", "long", "(sourceVal == null ? 0 : sourceVal.longValue())"),
        new ExpectedResult("java.lang.Long", "long[]", null),
        new ExpectedResult("java.lang.Long", "double", "(double)(sourceVal == null ? 0 : sourceVal.longValue())"),
        new ExpectedResult("java.lang.Long", "double[]", null),
        new ExpectedResult("java.lang.Long", "float", "(float)(sourceVal == null ? 0 : sourceVal.longValue())"),
        new ExpectedResult("java.lang.Long", "float[]", null),
        new ExpectedResult("java.lang.Long", "boolean", "((sourceVal == null ? 0 : sourceVal.longValue()) != 0)"),
        new ExpectedResult("java.lang.Long", "boolean[]", null),
        new ExpectedResult("java.lang.Long", "java.lang.Integer", "new java.lang.Integer((int)(sourceVal == null ? 0 : sourceVal.longValue()))"),
        new ExpectedResult("java.lang.Long", "java.lang.Integer[]", null),
        new ExpectedResult("java.lang.Long", "java.lang.Long", "sourceVal"),
        new ExpectedResult("java.lang.Long", "java.lang.Long[]", null),
        new ExpectedResult("java.lang.Long", "java.lang.Double", "new java.lang.Double((double)(sourceVal == null ? 0 : sourceVal.longValue()))"),
        new ExpectedResult("java.lang.Long", "java.lang.Double[]", null),
        new ExpectedResult("java.lang.Long", "java.lang.Float", "new java.lang.Float((float)(sourceVal == null ? 0 : sourceVal.longValue()))"),
        new ExpectedResult("java.lang.Long", "java.lang.Float[]", null),
        new ExpectedResult("java.lang.Long", "java.lang.Boolean", "new java.lang.Boolean(((sourceVal == null ? 0 : sourceVal.longValue()) != 0))"),
        new ExpectedResult("java.lang.Long", "java.lang.Boolean[]", null),
        new ExpectedResult("java.lang.Long", "java.util.Date", "new java.util.Date((sourceVal == null ? 0 : sourceVal.longValue()))"),
        new ExpectedResult("java.lang.Long", "java.util.Date[]", null),
        new ExpectedResult("java.lang.Long", "java.sql.Timestamp", "new java.sql.Timestamp((sourceVal == null ? 0 : sourceVal.longValue()))"),
        new ExpectedResult("java.lang.Long", "java.sql.Timestamp[]", null),
        new ExpectedResult("java.lang.Long", "java.sql.Time", "new java.sql.Time((sourceVal == null ? 0 : sourceVal.longValue()))"),
        new ExpectedResult("java.lang.Long", "java.sql.Time[]", null),
        new ExpectedResult("java.lang.Long", "java.sql.Date", "new java.sql.Date((sourceVal == null ? 0 : sourceVal.longValue()))"),
        new ExpectedResult("java.lang.Long", "java.sql.Date[]", null),
        new ExpectedResult("java.lang.Long", "java.lang.String", "(sourceVal == null ? null : sourceVal.toString())"),
        new ExpectedResult("java.lang.Long", "java.lang.String[]", null),
        new ExpectedResult("java.lang.Long", "com.example.UserClass1", null),
        new ExpectedResult("java.lang.Long", "com.example.UserClass1[]", null),
        new ExpectedResult("java.lang.Long", "com.example.UserClass2", null),
        new ExpectedResult("java.lang.Long", "com.example.UserClass2[]", null),
        new ExpectedResult("java.lang.Long", "java.math.BigInteger", "(sourceVal == null ? null : java.math.BigInteger.valueOf(sourceVal.longValue()))"),
        new ExpectedResult("java.lang.Long", "java.math.BigInteger[]", null),
        new ExpectedResult("java.lang.Long", "java.math.BigDecimal", "(sourceVal == null ? null : java.math.BigDecimal.valueOf(sourceVal.longValue()))"),
        new ExpectedResult("java.lang.Long", "java.math.BigDecimal[]", null),
        new ExpectedResult("java.lang.Long[]", "int", null),
        new ExpectedResult("java.lang.Long[]", "int[]", null),
        new ExpectedResult("java.lang.Long[]", "long", null),
        new ExpectedResult("java.lang.Long[]", "long[]", null),
        new ExpectedResult("java.lang.Long[]", "double", null),
        new ExpectedResult("java.lang.Long[]", "double[]", null),
        new ExpectedResult("java.lang.Long[]", "float", null),
        new ExpectedResult("java.lang.Long[]", "float[]", null),
        new ExpectedResult("java.lang.Long[]", "boolean", null),
        new ExpectedResult("java.lang.Long[]", "boolean[]", null),
        new ExpectedResult("java.lang.Long[]", "java.lang.Integer", null),
        new ExpectedResult("java.lang.Long[]", "java.lang.Integer[]", null),
        new ExpectedResult("java.lang.Long[]", "java.lang.Long", null),
        new ExpectedResult("java.lang.Long[]", "java.lang.Long[]", "sourceVal"),
        new ExpectedResult("java.lang.Long[]", "java.lang.Double", null),
        new ExpectedResult("java.lang.Long[]", "java.lang.Double[]", null),
        new ExpectedResult("java.lang.Long[]", "java.lang.Float", null),
        new ExpectedResult("java.lang.Long[]", "java.lang.Float[]", null),
        new ExpectedResult("java.lang.Long[]", "java.lang.Boolean", null),
        new ExpectedResult("java.lang.Long[]", "java.lang.Boolean[]", null),
        new ExpectedResult("java.lang.Long[]", "java.util.Date", null),
        new ExpectedResult("java.lang.Long[]", "java.util.Date[]", null),
        new ExpectedResult("java.lang.Long[]", "java.sql.Timestamp", null),
        new ExpectedResult("java.lang.Long[]", "java.sql.Timestamp[]", null),
        new ExpectedResult("java.lang.Long[]", "java.sql.Time", null),
        new ExpectedResult("java.lang.Long[]", "java.sql.Time[]", null),
        new ExpectedResult("java.lang.Long[]", "java.sql.Date", null),
        new ExpectedResult("java.lang.Long[]", "java.sql.Date[]", null),
        new ExpectedResult("java.lang.Long[]", "java.lang.String", null),
        new ExpectedResult("java.lang.Long[]", "java.lang.String[]", null),
        new ExpectedResult("java.lang.Long[]", "com.example.UserClass1", null),
        new ExpectedResult("java.lang.Long[]", "com.example.UserClass1[]", null),
        new ExpectedResult("java.lang.Long[]", "com.example.UserClass2", null),
        new ExpectedResult("java.lang.Long[]", "com.example.UserClass2[]", null),
        new ExpectedResult("java.lang.Long[]", "java.math.BigInteger", null),
        new ExpectedResult("java.lang.Long[]", "java.math.BigInteger[]", null),
        new ExpectedResult("java.lang.Long[]", "java.math.BigDecimal", null),
        new ExpectedResult("java.lang.Long[]", "java.math.BigDecimal[]", null),
        new ExpectedResult("java.lang.Double", "int", "(int)(sourceVal == null ? 0.0 : sourceVal.doubleValue())"),
        new ExpectedResult("java.lang.Double", "int[]", null),
        new ExpectedResult("java.lang.Double", "long", "(long)(sourceVal == null ? 0.0 : sourceVal.doubleValue())"),
        new ExpectedResult("java.lang.Double", "long[]", null),
        new ExpectedResult("java.lang.Double", "double", "(sourceVal == null ? 0.0 : sourceVal.doubleValue())"),
        new ExpectedResult("java.lang.Double", "double[]", null),
        new ExpectedResult("java.lang.Double", "float", "(float)(sourceVal == null ? 0.0 : sourceVal.doubleValue())"),
        new ExpectedResult("java.lang.Double", "float[]", null),
        new ExpectedResult("java.lang.Double", "boolean", "((sourceVal == null ? 0.0 : sourceVal.doubleValue()) != 0.0)"),
        new ExpectedResult("java.lang.Double", "boolean[]", null),
        new ExpectedResult("java.lang.Double", "java.lang.Integer", "new java.lang.Integer((int)(sourceVal == null ? 0.0 : sourceVal.doubleValue()))"),
        new ExpectedResult("java.lang.Double", "java.lang.Integer[]", null),
        new ExpectedResult("java.lang.Double", "java.lang.Long", "new java.lang.Long((long)(sourceVal == null ? 0.0 : sourceVal.doubleValue()))"),
        new ExpectedResult("java.lang.Double", "java.lang.Long[]", null),
        new ExpectedResult("java.lang.Double", "java.lang.Double", "sourceVal"),
        new ExpectedResult("java.lang.Double", "java.lang.Double[]", null),
        new ExpectedResult("java.lang.Double", "java.lang.Float", "new java.lang.Float((float)(sourceVal == null ? 0.0 : sourceVal.doubleValue()))"),
        new ExpectedResult("java.lang.Double", "java.lang.Float[]", null),
        new ExpectedResult("java.lang.Double", "java.lang.Boolean", "new java.lang.Boolean(((sourceVal == null ? 0.0 : sourceVal.doubleValue()) != 0.0))"),
        new ExpectedResult("java.lang.Double", "java.lang.Boolean[]", null),
        new ExpectedResult("java.lang.Double", "java.util.Date", null),
        new ExpectedResult("java.lang.Double", "java.util.Date[]", null),
        new ExpectedResult("java.lang.Double", "java.sql.Timestamp", null),
        new ExpectedResult("java.lang.Double", "java.sql.Timestamp[]", null),
        new ExpectedResult("java.lang.Double", "java.sql.Time", null),
        new ExpectedResult("java.lang.Double", "java.sql.Time[]", null),
        new ExpectedResult("java.lang.Double", "java.sql.Date", null),
        new ExpectedResult("java.lang.Double", "java.sql.Date[]", null),
        new ExpectedResult("java.lang.Double", "java.lang.String", "(sourceVal == null ? null : sourceVal.toString())"),
        new ExpectedResult("java.lang.Double", "java.lang.String[]", null),
        new ExpectedResult("java.lang.Double", "com.example.UserClass1", null),
        new ExpectedResult("java.lang.Double", "com.example.UserClass1[]", null),
        new ExpectedResult("java.lang.Double", "com.example.UserClass2", null),
        new ExpectedResult("java.lang.Double", "com.example.UserClass2[]", null),
        new ExpectedResult("java.lang.Double", "java.math.BigInteger", "(sourceVal == null ? null : new java.math.BigDecimal(sourceVal.doubleValue()).toBigInteger())"),
        new ExpectedResult("java.lang.Double", "java.math.BigInteger[]", null),
        new ExpectedResult("java.lang.Double", "java.math.BigDecimal", "(sourceVal == null ? null : new java.math.BigDecimal(sourceVal.doubleValue()))"),
        new ExpectedResult("java.lang.Double", "java.math.BigDecimal[]", null),
        new ExpectedResult("java.lang.Double[]", "int", null),
        new ExpectedResult("java.lang.Double[]", "int[]", null),
        new ExpectedResult("java.lang.Double[]", "long", null),
        new ExpectedResult("java.lang.Double[]", "long[]", null),
        new ExpectedResult("java.lang.Double[]", "double", null),
        new ExpectedResult("java.lang.Double[]", "double[]", null),
        new ExpectedResult("java.lang.Double[]", "float", null),
        new ExpectedResult("java.lang.Double[]", "float[]", null),
        new ExpectedResult("java.lang.Double[]", "boolean", null),
        new ExpectedResult("java.lang.Double[]", "boolean[]", null),
        new ExpectedResult("java.lang.Double[]", "java.lang.Integer", null),
        new ExpectedResult("java.lang.Double[]", "java.lang.Integer[]", null),
        new ExpectedResult("java.lang.Double[]", "java.lang.Long", null),
        new ExpectedResult("java.lang.Double[]", "java.lang.Long[]", null),
        new ExpectedResult("java.lang.Double[]", "java.lang.Double", null),
        new ExpectedResult("java.lang.Double[]", "java.lang.Double[]", "sourceVal"),
        new ExpectedResult("java.lang.Double[]", "java.lang.Float", null),
        new ExpectedResult("java.lang.Double[]", "java.lang.Float[]", null),
        new ExpectedResult("java.lang.Double[]", "java.lang.Boolean", null),
        new ExpectedResult("java.lang.Double[]", "java.lang.Boolean[]", null),
        new ExpectedResult("java.lang.Double[]", "java.util.Date", null),
        new ExpectedResult("java.lang.Double[]", "java.util.Date[]", null),
        new ExpectedResult("java.lang.Double[]", "java.sql.Timestamp", null),
        new ExpectedResult("java.lang.Double[]", "java.sql.Timestamp[]", null),
        new ExpectedResult("java.lang.Double[]", "java.sql.Time", null),
        new ExpectedResult("java.lang.Double[]", "java.sql.Time[]", null),
        new ExpectedResult("java.lang.Double[]", "java.sql.Date", null),
        new ExpectedResult("java.lang.Double[]", "java.sql.Date[]", null),
        new ExpectedResult("java.lang.Double[]", "java.lang.String", null),
        new ExpectedResult("java.lang.Double[]", "java.lang.String[]", null),
        new ExpectedResult("java.lang.Double[]", "com.example.UserClass1", null),
        new ExpectedResult("java.lang.Double[]", "com.example.UserClass1[]", null),
        new ExpectedResult("java.lang.Double[]", "com.example.UserClass2", null),
        new ExpectedResult("java.lang.Double[]", "com.example.UserClass2[]", null),
        new ExpectedResult("java.lang.Double[]", "java.math.BigInteger", null),
        new ExpectedResult("java.lang.Double[]", "java.math.BigInteger[]", null),
        new ExpectedResult("java.lang.Double[]", "java.math.BigDecimal", null),
        new ExpectedResult("java.lang.Double[]", "java.math.BigDecimal[]", null),
        new ExpectedResult("java.lang.Float", "int", "(int)(sourceVal == null ? 0.0f : sourceVal.floatValue())"),
        new ExpectedResult("java.lang.Float", "int[]", null),
        new ExpectedResult("java.lang.Float", "long", "(long)(sourceVal == null ? 0.0f : sourceVal.floatValue())"),
        new ExpectedResult("java.lang.Float", "long[]", null),
        new ExpectedResult("java.lang.Float", "double", "(double)(sourceVal == null ? 0.0f : sourceVal.floatValue())"),
        new ExpectedResult("java.lang.Float", "double[]", null),
        new ExpectedResult("java.lang.Float", "float", "(sourceVal == null ? 0.0f : sourceVal.floatValue())"),
        new ExpectedResult("java.lang.Float", "float[]", null),
        new ExpectedResult("java.lang.Float", "boolean", "((sourceVal == null ? 0.0f : sourceVal.floatValue()) != 0.0f)"),
        new ExpectedResult("java.lang.Float", "boolean[]", null),
        new ExpectedResult("java.lang.Float", "java.lang.Integer", "new java.lang.Integer((int)(sourceVal == null ? 0.0f : sourceVal.floatValue()))"),
        new ExpectedResult("java.lang.Float", "java.lang.Integer[]", null),
        new ExpectedResult("java.lang.Float", "java.lang.Long", "new java.lang.Long((long)(sourceVal == null ? 0.0f : sourceVal.floatValue()))"),
        new ExpectedResult("java.lang.Float", "java.lang.Long[]", null),
        new ExpectedResult("java.lang.Float", "java.lang.Double", "new java.lang.Double((double)(sourceVal == null ? 0.0f : sourceVal.floatValue()))"),
        new ExpectedResult("java.lang.Float", "java.lang.Double[]", null),
        new ExpectedResult("java.lang.Float", "java.lang.Float", "sourceVal"),
        new ExpectedResult("java.lang.Float", "java.lang.Float[]", null),
        new ExpectedResult("java.lang.Float", "java.lang.Boolean", "new java.lang.Boolean(((sourceVal == null ? 0.0f : sourceVal.floatValue()) != 0.0f))"),
        new ExpectedResult("java.lang.Float", "java.lang.Boolean[]", null),
        new ExpectedResult("java.lang.Float", "java.util.Date", null),
        new ExpectedResult("java.lang.Float", "java.util.Date[]", null),
        new ExpectedResult("java.lang.Float", "java.sql.Timestamp", null),
        new ExpectedResult("java.lang.Float", "java.sql.Timestamp[]", null),
        new ExpectedResult("java.lang.Float", "java.sql.Time", null),
        new ExpectedResult("java.lang.Float", "java.sql.Time[]", null),
        new ExpectedResult("java.lang.Float", "java.sql.Date", null),
        new ExpectedResult("java.lang.Float", "java.sql.Date[]", null),
        new ExpectedResult("java.lang.Float", "java.lang.String", "(sourceVal == null ? null : sourceVal.toString())"),
        new ExpectedResult("java.lang.Float", "java.lang.String[]", null),
        new ExpectedResult("java.lang.Float", "com.example.UserClass1", null),
        new ExpectedResult("java.lang.Float", "com.example.UserClass1[]", null),
        new ExpectedResult("java.lang.Float", "com.example.UserClass2", null),
        new ExpectedResult("java.lang.Float", "com.example.UserClass2[]", null),
        new ExpectedResult("java.lang.Float", "java.math.BigInteger", "(sourceVal == null ? null : new java.math.BigDecimal((double)sourceVal.floatValue()).toBigInteger())"),
        new ExpectedResult("java.lang.Float", "java.math.BigInteger[]", null),
        new ExpectedResult("java.lang.Float", "java.math.BigDecimal", "(sourceVal == null ? null : new java.math.BigDecimal((double)sourceVal.floatValue()))"),
        new ExpectedResult("java.lang.Float", "java.math.BigDecimal[]", null),
        new ExpectedResult("java.lang.Float[]", "int", null),
        new ExpectedResult("java.lang.Float[]", "int[]", null),
        new ExpectedResult("java.lang.Float[]", "long", null),
        new ExpectedResult("java.lang.Float[]", "long[]", null),
        new ExpectedResult("java.lang.Float[]", "double", null),
        new ExpectedResult("java.lang.Float[]", "double[]", null),
        new ExpectedResult("java.lang.Float[]", "float", null),
        new ExpectedResult("java.lang.Float[]", "float[]", null),
        new ExpectedResult("java.lang.Float[]", "boolean", null),
        new ExpectedResult("java.lang.Float[]", "boolean[]", null),
        new ExpectedResult("java.lang.Float[]", "java.lang.Integer", null),
        new ExpectedResult("java.lang.Float[]", "java.lang.Integer[]", null),
        new ExpectedResult("java.lang.Float[]", "java.lang.Long", null),
        new ExpectedResult("java.lang.Float[]", "java.lang.Long[]", null),
        new ExpectedResult("java.lang.Float[]", "java.lang.Double", null),
        new ExpectedResult("java.lang.Float[]", "java.lang.Double[]", null),
        new ExpectedResult("java.lang.Float[]", "java.lang.Float", null),
        new ExpectedResult("java.lang.Float[]", "java.lang.Float[]", "sourceVal"),
        new ExpectedResult("java.lang.Float[]", "java.lang.Boolean", null),
        new ExpectedResult("java.lang.Float[]", "java.lang.Boolean[]", null),
        new ExpectedResult("java.lang.Float[]", "java.util.Date", null),
        new ExpectedResult("java.lang.Float[]", "java.util.Date[]", null),
        new ExpectedResult("java.lang.Float[]", "java.sql.Timestamp", null),
        new ExpectedResult("java.lang.Float[]", "java.sql.Timestamp[]", null),
        new ExpectedResult("java.lang.Float[]", "java.sql.Time", null),
        new ExpectedResult("java.lang.Float[]", "java.sql.Time[]", null),
        new ExpectedResult("java.lang.Float[]", "java.sql.Date", null),
        new ExpectedResult("java.lang.Float[]", "java.sql.Date[]", null),
        new ExpectedResult("java.lang.Float[]", "java.lang.String", null),
        new ExpectedResult("java.lang.Float[]", "java.lang.String[]", null),
        new ExpectedResult("java.lang.Float[]", "com.example.UserClass1", null),
        new ExpectedResult("java.lang.Float[]", "com.example.UserClass1[]", null),
        new ExpectedResult("java.lang.Float[]", "com.example.UserClass2", null),
        new ExpectedResult("java.lang.Float[]", "com.example.UserClass2[]", null),
        new ExpectedResult("java.lang.Float[]", "java.math.BigInteger", null),
        new ExpectedResult("java.lang.Float[]", "java.math.BigInteger[]", null),
        new ExpectedResult("java.lang.Float[]", "java.math.BigDecimal", null),
        new ExpectedResult("java.lang.Float[]", "java.math.BigDecimal[]", null),
        new ExpectedResult("java.lang.Boolean", "int", "((sourceVal == null ? false : sourceVal.booleanValue()) ? 1 : 0)"),
        new ExpectedResult("java.lang.Boolean", "int[]", null),
        new ExpectedResult("java.lang.Boolean", "long", "((sourceVal == null ? false : sourceVal.booleanValue()) ? 1 : 0)"),
        new ExpectedResult("java.lang.Boolean", "long[]", null),
        new ExpectedResult("java.lang.Boolean", "double", "((sourceVal == null ? false : sourceVal.booleanValue()) ? 1.0 : 0.0)"),
        new ExpectedResult("java.lang.Boolean", "double[]", null),
        new ExpectedResult("java.lang.Boolean", "float", "((sourceVal == null ? false : sourceVal.booleanValue()) ? 1.0f : 0.0f)"),
        new ExpectedResult("java.lang.Boolean", "float[]", null),
        new ExpectedResult("java.lang.Boolean", "boolean", "(sourceVal == null ? false : sourceVal.booleanValue())"),
        new ExpectedResult("java.lang.Boolean", "boolean[]", null),
        new ExpectedResult("java.lang.Boolean", "java.lang.Integer", "new java.lang.Integer(((sourceVal == null ? false : sourceVal.booleanValue()) ? 1 : 0))"),
        new ExpectedResult("java.lang.Boolean", "java.lang.Integer[]", null),
        new ExpectedResult("java.lang.Boolean", "java.lang.Long", "new java.lang.Long(((sourceVal == null ? false : sourceVal.booleanValue()) ? 1 : 0))"),
        new ExpectedResult("java.lang.Boolean", "java.lang.Long[]", null),
        new ExpectedResult("java.lang.Boolean", "java.lang.Double", "new java.lang.Double(((sourceVal == null ? false : sourceVal.booleanValue()) ? 1.0 : 0.0))"),
        new ExpectedResult("java.lang.Boolean", "java.lang.Double[]", null),
        new ExpectedResult("java.lang.Boolean", "java.lang.Float", "new java.lang.Float(((sourceVal == null ? false : sourceVal.booleanValue()) ? 1.0f : 0.0f))"),
        new ExpectedResult("java.lang.Boolean", "java.lang.Float[]", null),
        new ExpectedResult("java.lang.Boolean", "java.lang.Boolean", "sourceVal"),
        new ExpectedResult("java.lang.Boolean", "java.lang.Boolean[]", null),
        new ExpectedResult("java.lang.Boolean", "java.util.Date", null),
        new ExpectedResult("java.lang.Boolean", "java.util.Date[]", null),
        new ExpectedResult("java.lang.Boolean", "java.sql.Timestamp", null),
        new ExpectedResult("java.lang.Boolean", "java.sql.Timestamp[]", null),
        new ExpectedResult("java.lang.Boolean", "java.sql.Time", null),
        new ExpectedResult("java.lang.Boolean", "java.sql.Time[]", null),
        new ExpectedResult("java.lang.Boolean", "java.sql.Date", null),
        new ExpectedResult("java.lang.Boolean", "java.sql.Date[]", null),
        new ExpectedResult("java.lang.Boolean", "java.lang.String", "(sourceVal == null ? null : sourceVal.toString())"),
        new ExpectedResult("java.lang.Boolean", "java.lang.String[]", null),
        new ExpectedResult("java.lang.Boolean", "com.example.UserClass1", null),
        new ExpectedResult("java.lang.Boolean", "com.example.UserClass1[]", null),
        new ExpectedResult("java.lang.Boolean", "com.example.UserClass2", null),
        new ExpectedResult("java.lang.Boolean", "com.example.UserClass2[]", null),
        new ExpectedResult("java.lang.Boolean", "java.math.BigInteger", null),
        new ExpectedResult("java.lang.Boolean", "java.math.BigInteger[]", null),
        new ExpectedResult("java.lang.Boolean", "java.math.BigDecimal", null),
        new ExpectedResult("java.lang.Boolean", "java.math.BigDecimal[]", null),
        new ExpectedResult("java.lang.Boolean[]", "int", null),
        new ExpectedResult("java.lang.Boolean[]", "int[]", null),
        new ExpectedResult("java.lang.Boolean[]", "long", null),
        new ExpectedResult("java.lang.Boolean[]", "long[]", null),
        new ExpectedResult("java.lang.Boolean[]", "double", null),
        new ExpectedResult("java.lang.Boolean[]", "double[]", null),
        new ExpectedResult("java.lang.Boolean[]", "float", null),
        new ExpectedResult("java.lang.Boolean[]", "float[]", null),
        new ExpectedResult("java.lang.Boolean[]", "boolean", null),
        new ExpectedResult("java.lang.Boolean[]", "boolean[]", null),
        new ExpectedResult("java.lang.Boolean[]", "java.lang.Integer", null),
        new ExpectedResult("java.lang.Boolean[]", "java.lang.Integer[]", null),
        new ExpectedResult("java.lang.Boolean[]", "java.lang.Long", null),
        new ExpectedResult("java.lang.Boolean[]", "java.lang.Long[]", null),
        new ExpectedResult("java.lang.Boolean[]", "java.lang.Double", null),
        new ExpectedResult("java.lang.Boolean[]", "java.lang.Double[]", null),
        new ExpectedResult("java.lang.Boolean[]", "java.lang.Float", null),
        new ExpectedResult("java.lang.Boolean[]", "java.lang.Float[]", null),
        new ExpectedResult("java.lang.Boolean[]", "java.lang.Boolean", null),
        new ExpectedResult("java.lang.Boolean[]", "java.lang.Boolean[]", "sourceVal"),
        new ExpectedResult("java.lang.Boolean[]", "java.util.Date", null),
        new ExpectedResult("java.lang.Boolean[]", "java.util.Date[]", null),
        new ExpectedResult("java.lang.Boolean[]", "java.sql.Timestamp", null),
        new ExpectedResult("java.lang.Boolean[]", "java.sql.Timestamp[]", null),
        new ExpectedResult("java.lang.Boolean[]", "java.sql.Time", null),
        new ExpectedResult("java.lang.Boolean[]", "java.sql.Time[]", null),
        new ExpectedResult("java.lang.Boolean[]", "java.sql.Date", null),
        new ExpectedResult("java.lang.Boolean[]", "java.sql.Date[]", null),
        new ExpectedResult("java.lang.Boolean[]", "java.lang.String", null),
        new ExpectedResult("java.lang.Boolean[]", "java.lang.String[]", null),
        new ExpectedResult("java.lang.Boolean[]", "com.example.UserClass1", null),
        new ExpectedResult("java.lang.Boolean[]", "com.example.UserClass1[]", null),
        new ExpectedResult("java.lang.Boolean[]", "com.example.UserClass2", null),
        new ExpectedResult("java.lang.Boolean[]", "com.example.UserClass2[]", null),
        new ExpectedResult("java.lang.Boolean[]", "java.math.BigInteger", null),
        new ExpectedResult("java.lang.Boolean[]", "java.math.BigInteger[]", null),
        new ExpectedResult("java.lang.Boolean[]", "java.math.BigDecimal", null),
        new ExpectedResult("java.lang.Boolean[]", "java.math.BigDecimal[]", null),
        new ExpectedResult("java.util.Date", "int", null),
        new ExpectedResult("java.util.Date", "int[]", null),
        new ExpectedResult("java.util.Date", "long", "(sourceVal == null ? 0 : sourceVal.getTime())"),
        new ExpectedResult("java.util.Date", "long[]", null),
        new ExpectedResult("java.util.Date", "double", null),
        new ExpectedResult("java.util.Date", "double[]", null),
        new ExpectedResult("java.util.Date", "float", null),
        new ExpectedResult("java.util.Date", "float[]", null),
        new ExpectedResult("java.util.Date", "boolean", null),
        new ExpectedResult("java.util.Date", "boolean[]", null),
        new ExpectedResult("java.util.Date", "java.lang.Integer", null),
        new ExpectedResult("java.util.Date", "java.lang.Integer[]", null),
        new ExpectedResult("java.util.Date", "java.lang.Long", "new java.lang.Long((sourceVal == null ? 0 : sourceVal.getTime()))"),
        new ExpectedResult("java.util.Date", "java.lang.Long[]", null),
        new ExpectedResult("java.util.Date", "java.lang.Double", null),
        new ExpectedResult("java.util.Date", "java.lang.Double[]", null),
        new ExpectedResult("java.util.Date", "java.lang.Float", null),
        new ExpectedResult("java.util.Date", "java.lang.Float[]", null),
        new ExpectedResult("java.util.Date", "java.lang.Boolean", null),
        new ExpectedResult("java.util.Date", "java.lang.Boolean[]", null),
        new ExpectedResult("java.util.Date", "java.util.Date", "sourceVal"),
        new ExpectedResult("java.util.Date", "java.util.Date[]", null),
        new ExpectedResult("java.util.Date", "java.sql.Timestamp", "(sourceVal == null ? null : new java.sql.Timestamp(sourceVal.getTime()))"),
        new ExpectedResult("java.util.Date", "java.sql.Timestamp[]", null),
        new ExpectedResult("java.util.Date", "java.sql.Time", "(sourceVal == null ? null : new java.sql.Time(sourceVal.getTime()))"),
        new ExpectedResult("java.util.Date", "java.sql.Time[]", null),
        new ExpectedResult("java.util.Date", "java.sql.Date", "(sourceVal == null ? null : new java.sql.Date(sourceVal.getTime()))"),
        new ExpectedResult("java.util.Date", "java.sql.Date[]", null),
        new ExpectedResult("java.util.Date", "java.lang.String", "(sourceVal == null ? null : new java.text.SimpleDateFormat(\"yyyy-MM-dd HH:mm:ssZ\").format(sourceVal))"),
        new ExpectedResult("java.util.Date", "java.lang.String[]", null),
        new ExpectedResult("java.util.Date", "com.example.UserClass1", null),
        new ExpectedResult("java.util.Date", "com.example.UserClass1[]", null),
        new ExpectedResult("java.util.Date", "com.example.UserClass2", null),
        new ExpectedResult("java.util.Date", "com.example.UserClass2[]", null),
        new ExpectedResult("java.util.Date", "java.math.BigInteger", null),
        new ExpectedResult("java.util.Date", "java.math.BigInteger[]", null),
        new ExpectedResult("java.util.Date", "java.math.BigDecimal", null),
        new ExpectedResult("java.util.Date", "java.math.BigDecimal[]", null),
        new ExpectedResult("java.util.Date[]", "int", null),
        new ExpectedResult("java.util.Date[]", "int[]", null),
        new ExpectedResult("java.util.Date[]", "long", null),
        new ExpectedResult("java.util.Date[]", "long[]", null),
        new ExpectedResult("java.util.Date[]", "double", null),
        new ExpectedResult("java.util.Date[]", "double[]", null),
        new ExpectedResult("java.util.Date[]", "float", null),
        new ExpectedResult("java.util.Date[]", "float[]", null),
        new ExpectedResult("java.util.Date[]", "boolean", null),
        new ExpectedResult("java.util.Date[]", "boolean[]", null),
        new ExpectedResult("java.util.Date[]", "java.lang.Integer", null),
        new ExpectedResult("java.util.Date[]", "java.lang.Integer[]", null),
        new ExpectedResult("java.util.Date[]", "java.lang.Long", null),
        new ExpectedResult("java.util.Date[]", "java.lang.Long[]", null),
        new ExpectedResult("java.util.Date[]", "java.lang.Double", null),
        new ExpectedResult("java.util.Date[]", "java.lang.Double[]", null),
        new ExpectedResult("java.util.Date[]", "java.lang.Float", null),
        new ExpectedResult("java.util.Date[]", "java.lang.Float[]", null),
        new ExpectedResult("java.util.Date[]", "java.lang.Boolean", null),
        new ExpectedResult("java.util.Date[]", "java.lang.Boolean[]", null),
        new ExpectedResult("java.util.Date[]", "java.util.Date", null),
        new ExpectedResult("java.util.Date[]", "java.util.Date[]", "sourceVal"),
        new ExpectedResult("java.util.Date[]", "java.sql.Timestamp", null),
        new ExpectedResult("java.util.Date[]", "java.sql.Timestamp[]", null),
        new ExpectedResult("java.util.Date[]", "java.sql.Time", null),
        new ExpectedResult("java.util.Date[]", "java.sql.Time[]", null),
        new ExpectedResult("java.util.Date[]", "java.sql.Date", null),
        new ExpectedResult("java.util.Date[]", "java.sql.Date[]", null),
        new ExpectedResult("java.util.Date[]", "java.lang.String", null),
        new ExpectedResult("java.util.Date[]", "java.lang.String[]", null),
        new ExpectedResult("java.util.Date[]", "com.example.UserClass1", null),
        new ExpectedResult("java.util.Date[]", "com.example.UserClass1[]", null),
        new ExpectedResult("java.util.Date[]", "com.example.UserClass2", null),
        new ExpectedResult("java.util.Date[]", "com.example.UserClass2[]", null),
        new ExpectedResult("java.util.Date[]", "java.math.BigInteger", null),
        new ExpectedResult("java.util.Date[]", "java.math.BigInteger[]", null),
        new ExpectedResult("java.util.Date[]", "java.math.BigDecimal", null),
        new ExpectedResult("java.util.Date[]", "java.math.BigDecimal[]", null),
        new ExpectedResult("java.sql.Timestamp", "int", null),
        new ExpectedResult("java.sql.Timestamp", "int[]", null),
        new ExpectedResult("java.sql.Timestamp", "long", "(sourceVal == null ? 0 : sourceVal.getTime())"),
        new ExpectedResult("java.sql.Timestamp", "long[]", null),
        new ExpectedResult("java.sql.Timestamp", "double", null),
        new ExpectedResult("java.sql.Timestamp", "double[]", null),
        new ExpectedResult("java.sql.Timestamp", "float", null),
        new ExpectedResult("java.sql.Timestamp", "float[]", null),
        new ExpectedResult("java.sql.Timestamp", "boolean", null),
        new ExpectedResult("java.sql.Timestamp", "boolean[]", null),
        new ExpectedResult("java.sql.Timestamp", "java.lang.Integer", null),
        new ExpectedResult("java.sql.Timestamp", "java.lang.Integer[]", null),
        new ExpectedResult("java.sql.Timestamp", "java.lang.Long", "new java.lang.Long((sourceVal == null ? 0 : sourceVal.getTime()))"),
        new ExpectedResult("java.sql.Timestamp", "java.lang.Long[]", null),
        new ExpectedResult("java.sql.Timestamp", "java.lang.Double", null),
        new ExpectedResult("java.sql.Timestamp", "java.lang.Double[]", null),
        new ExpectedResult("java.sql.Timestamp", "java.lang.Float", null),
        new ExpectedResult("java.sql.Timestamp", "java.lang.Float[]", null),
        new ExpectedResult("java.sql.Timestamp", "java.lang.Boolean", null),
        new ExpectedResult("java.sql.Timestamp", "java.lang.Boolean[]", null),
        new ExpectedResult("java.sql.Timestamp", "java.util.Date", "sourceVal"),
        new ExpectedResult("java.sql.Timestamp", "java.util.Date[]", null),
        new ExpectedResult("java.sql.Timestamp", "java.sql.Timestamp", "sourceVal"),
        new ExpectedResult("java.sql.Timestamp", "java.sql.Timestamp[]", null),
        new ExpectedResult("java.sql.Timestamp", "java.sql.Time", "(sourceVal == null ? null : new java.sql.Time(sourceVal.getTime()))"),
        new ExpectedResult("java.sql.Timestamp", "java.sql.Time[]", null),
        new ExpectedResult("java.sql.Timestamp", "java.sql.Date", "(sourceVal == null ? null : new java.sql.Date(sourceVal.getTime()))"),
        new ExpectedResult("java.sql.Timestamp", "java.sql.Date[]", null),
        new ExpectedResult("java.sql.Timestamp", "java.lang.String", "(sourceVal == null ? null : new java.text.SimpleDateFormat(\"yyyy-MM-dd HH:mm:ssZ\").format(sourceVal))"),
        new ExpectedResult("java.sql.Timestamp", "java.lang.String[]", null),
        new ExpectedResult("java.sql.Timestamp", "com.example.UserClass1", null),
        new ExpectedResult("java.sql.Timestamp", "com.example.UserClass1[]", null),
        new ExpectedResult("java.sql.Timestamp", "com.example.UserClass2", null),
        new ExpectedResult("java.sql.Timestamp", "com.example.UserClass2[]", null),
        new ExpectedResult("java.sql.Timestamp", "java.math.BigInteger", null),
        new ExpectedResult("java.sql.Timestamp", "java.math.BigInteger[]", null),
        new ExpectedResult("java.sql.Timestamp", "java.math.BigDecimal", null),
        new ExpectedResult("java.sql.Timestamp", "java.math.BigDecimal[]", null),
        new ExpectedResult("java.sql.Timestamp[]", "int", null),
        new ExpectedResult("java.sql.Timestamp[]", "int[]", null),
        new ExpectedResult("java.sql.Timestamp[]", "long", null),
        new ExpectedResult("java.sql.Timestamp[]", "long[]", null),
        new ExpectedResult("java.sql.Timestamp[]", "double", null),
        new ExpectedResult("java.sql.Timestamp[]", "double[]", null),
        new ExpectedResult("java.sql.Timestamp[]", "float", null),
        new ExpectedResult("java.sql.Timestamp[]", "float[]", null),
        new ExpectedResult("java.sql.Timestamp[]", "boolean", null),
        new ExpectedResult("java.sql.Timestamp[]", "boolean[]", null),
        new ExpectedResult("java.sql.Timestamp[]", "java.lang.Integer", null),
        new ExpectedResult("java.sql.Timestamp[]", "java.lang.Integer[]", null),
        new ExpectedResult("java.sql.Timestamp[]", "java.lang.Long", null),
        new ExpectedResult("java.sql.Timestamp[]", "java.lang.Long[]", null),
        new ExpectedResult("java.sql.Timestamp[]", "java.lang.Double", null),
        new ExpectedResult("java.sql.Timestamp[]", "java.lang.Double[]", null),
        new ExpectedResult("java.sql.Timestamp[]", "java.lang.Float", null),
        new ExpectedResult("java.sql.Timestamp[]", "java.lang.Float[]", null),
        new ExpectedResult("java.sql.Timestamp[]", "java.lang.Boolean", null),
        new ExpectedResult("java.sql.Timestamp[]", "java.lang.Boolean[]", null),
        new ExpectedResult("java.sql.Timestamp[]", "java.util.Date", null),
        new ExpectedResult("java.sql.Timestamp[]", "java.util.Date[]", null),
        new ExpectedResult("java.sql.Timestamp[]", "java.sql.Timestamp", null),
        new ExpectedResult("java.sql.Timestamp[]", "java.sql.Timestamp[]", "sourceVal"),
        new ExpectedResult("java.sql.Timestamp[]", "java.sql.Time", null),
        new ExpectedResult("java.sql.Timestamp[]", "java.sql.Time[]", null),
        new ExpectedResult("java.sql.Timestamp[]", "java.sql.Date", null),
        new ExpectedResult("java.sql.Timestamp[]", "java.sql.Date[]", null),
        new ExpectedResult("java.sql.Timestamp[]", "java.lang.String", null),
        new ExpectedResult("java.sql.Timestamp[]", "java.lang.String[]", null),
        new ExpectedResult("java.sql.Timestamp[]", "com.example.UserClass1", null),
        new ExpectedResult("java.sql.Timestamp[]", "com.example.UserClass1[]", null),
        new ExpectedResult("java.sql.Timestamp[]", "com.example.UserClass2", null),
        new ExpectedResult("java.sql.Timestamp[]", "com.example.UserClass2[]", null),
        new ExpectedResult("java.sql.Timestamp[]", "java.math.BigInteger", null),
        new ExpectedResult("java.sql.Timestamp[]", "java.math.BigInteger[]", null),
        new ExpectedResult("java.sql.Timestamp[]", "java.math.BigDecimal", null),
        new ExpectedResult("java.sql.Timestamp[]", "java.math.BigDecimal[]", null),
        new ExpectedResult("java.sql.Time", "int", null),
        new ExpectedResult("java.sql.Time", "int[]", null),
        new ExpectedResult("java.sql.Time", "long", "(sourceVal == null ? 0 : sourceVal.getTime())"),
        new ExpectedResult("java.sql.Time", "long[]", null),
        new ExpectedResult("java.sql.Time", "double", null),
        new ExpectedResult("java.sql.Time", "double[]", null),
        new ExpectedResult("java.sql.Time", "float", null),
        new ExpectedResult("java.sql.Time", "float[]", null),
        new ExpectedResult("java.sql.Time", "boolean", null),
        new ExpectedResult("java.sql.Time", "boolean[]", null),
        new ExpectedResult("java.sql.Time", "java.lang.Integer", null),
        new ExpectedResult("java.sql.Time", "java.lang.Integer[]", null),
        new ExpectedResult("java.sql.Time", "java.lang.Long", "new java.lang.Long((sourceVal == null ? 0 : sourceVal.getTime()))"),
        new ExpectedResult("java.sql.Time", "java.lang.Long[]", null),
        new ExpectedResult("java.sql.Time", "java.lang.Double", null),
        new ExpectedResult("java.sql.Time", "java.lang.Double[]", null),
        new ExpectedResult("java.sql.Time", "java.lang.Float", null),
        new ExpectedResult("java.sql.Time", "java.lang.Float[]", null),
        new ExpectedResult("java.sql.Time", "java.lang.Boolean", null),
        new ExpectedResult("java.sql.Time", "java.lang.Boolean[]", null),
        new ExpectedResult("java.sql.Time", "java.util.Date", "sourceVal"),
        new ExpectedResult("java.sql.Time", "java.util.Date[]", null),
        new ExpectedResult("java.sql.Time", "java.sql.Timestamp", "(sourceVal == null ? null : new java.sql.Timestamp(sourceVal.getTime()))"),
        new ExpectedResult("java.sql.Time", "java.sql.Timestamp[]", null),
        new ExpectedResult("java.sql.Time", "java.sql.Time", "sourceVal"),
        new ExpectedResult("java.sql.Time", "java.sql.Time[]", null),
        new ExpectedResult("java.sql.Time", "java.sql.Date", null),
        new ExpectedResult("java.sql.Time", "java.sql.Date[]", null),
        new ExpectedResult("java.sql.Time", "java.lang.String", "(sourceVal == null ? null : new java.text.SimpleDateFormat(\"HH:mm:ssZ\").format(sourceVal))"),
        new ExpectedResult("java.sql.Time", "java.lang.String[]", null),
        new ExpectedResult("java.sql.Time", "com.example.UserClass1", null),
        new ExpectedResult("java.sql.Time", "com.example.UserClass1[]", null),
        new ExpectedResult("java.sql.Time", "com.example.UserClass2", null),
        new ExpectedResult("java.sql.Time", "com.example.UserClass2[]", null),
        new ExpectedResult("java.sql.Time", "java.math.BigInteger", null),
        new ExpectedResult("java.sql.Time", "java.math.BigInteger[]", null),
        new ExpectedResult("java.sql.Time", "java.math.BigDecimal", null),
        new ExpectedResult("java.sql.Time", "java.math.BigDecimal[]", null),
        new ExpectedResult("java.sql.Time[]", "int", null),
        new ExpectedResult("java.sql.Time[]", "int[]", null),
        new ExpectedResult("java.sql.Time[]", "long", null),
        new ExpectedResult("java.sql.Time[]", "long[]", null),
        new ExpectedResult("java.sql.Time[]", "double", null),
        new ExpectedResult("java.sql.Time[]", "double[]", null),
        new ExpectedResult("java.sql.Time[]", "float", null),
        new ExpectedResult("java.sql.Time[]", "float[]", null),
        new ExpectedResult("java.sql.Time[]", "boolean", null),
        new ExpectedResult("java.sql.Time[]", "boolean[]", null),
        new ExpectedResult("java.sql.Time[]", "java.lang.Integer", null),
        new ExpectedResult("java.sql.Time[]", "java.lang.Integer[]", null),
        new ExpectedResult("java.sql.Time[]", "java.lang.Long", null),
        new ExpectedResult("java.sql.Time[]", "java.lang.Long[]", null),
        new ExpectedResult("java.sql.Time[]", "java.lang.Double", null),
        new ExpectedResult("java.sql.Time[]", "java.lang.Double[]", null),
        new ExpectedResult("java.sql.Time[]", "java.lang.Float", null),
        new ExpectedResult("java.sql.Time[]", "java.lang.Float[]", null),
        new ExpectedResult("java.sql.Time[]", "java.lang.Boolean", null),
        new ExpectedResult("java.sql.Time[]", "java.lang.Boolean[]", null),
        new ExpectedResult("java.sql.Time[]", "java.util.Date", null),
        new ExpectedResult("java.sql.Time[]", "java.util.Date[]", null),
        new ExpectedResult("java.sql.Time[]", "java.sql.Timestamp", null),
        new ExpectedResult("java.sql.Time[]", "java.sql.Timestamp[]", null),
        new ExpectedResult("java.sql.Time[]", "java.sql.Time", null),
        new ExpectedResult("java.sql.Time[]", "java.sql.Time[]", "sourceVal"),
        new ExpectedResult("java.sql.Time[]", "java.sql.Date", null),
        new ExpectedResult("java.sql.Time[]", "java.sql.Date[]", null),
        new ExpectedResult("java.sql.Time[]", "java.lang.String", null),
        new ExpectedResult("java.sql.Time[]", "java.lang.String[]", null),
        new ExpectedResult("java.sql.Time[]", "com.example.UserClass1", null),
        new ExpectedResult("java.sql.Time[]", "com.example.UserClass1[]", null),
        new ExpectedResult("java.sql.Time[]", "com.example.UserClass2", null),
        new ExpectedResult("java.sql.Time[]", "com.example.UserClass2[]", null),
        new ExpectedResult("java.sql.Time[]", "java.math.BigInteger", null),
        new ExpectedResult("java.sql.Time[]", "java.math.BigInteger[]", null),
        new ExpectedResult("java.sql.Time[]", "java.math.BigDecimal", null),
        new ExpectedResult("java.sql.Time[]", "java.math.BigDecimal[]", null),
        new ExpectedResult("java.sql.Date", "int", null),
        new ExpectedResult("java.sql.Date", "int[]", null),
        new ExpectedResult("java.sql.Date", "long", "(sourceVal == null ? 0 : sourceVal.getTime())"),
        new ExpectedResult("java.sql.Date", "long[]", null),
        new ExpectedResult("java.sql.Date", "double", null),
        new ExpectedResult("java.sql.Date", "double[]", null),
        new ExpectedResult("java.sql.Date", "float", null),
        new ExpectedResult("java.sql.Date", "float[]", null),
        new ExpectedResult("java.sql.Date", "boolean", null),
        new ExpectedResult("java.sql.Date", "boolean[]", null),
        new ExpectedResult("java.sql.Date", "java.lang.Integer", null),
        new ExpectedResult("java.sql.Date", "java.lang.Integer[]", null),
        new ExpectedResult("java.sql.Date", "java.lang.Long", "new java.lang.Long((sourceVal == null ? 0 : sourceVal.getTime()))"),
        new ExpectedResult("java.sql.Date", "java.lang.Long[]", null),
        new ExpectedResult("java.sql.Date", "java.lang.Double", null),
        new ExpectedResult("java.sql.Date", "java.lang.Double[]", null),
        new ExpectedResult("java.sql.Date", "java.lang.Float", null),
        new ExpectedResult("java.sql.Date", "java.lang.Float[]", null),
        new ExpectedResult("java.sql.Date", "java.lang.Boolean", null),
        new ExpectedResult("java.sql.Date", "java.lang.Boolean[]", null),
        new ExpectedResult("java.sql.Date", "java.util.Date", "sourceVal"),
        new ExpectedResult("java.sql.Date", "java.util.Date[]", null),
        new ExpectedResult("java.sql.Date", "java.sql.Timestamp", "(sourceVal == null ? null : new java.sql.Timestamp(sourceVal.getTime()))"),
        new ExpectedResult("java.sql.Date", "java.sql.Timestamp[]", null),
        new ExpectedResult("java.sql.Date", "java.sql.Time", null),
        new ExpectedResult("java.sql.Date", "java.sql.Time[]", null),
        new ExpectedResult("java.sql.Date", "java.sql.Date", "sourceVal"),
        new ExpectedResult("java.sql.Date", "java.sql.Date[]", null),
        new ExpectedResult("java.sql.Date", "java.lang.String", "(sourceVal == null ? null : new java.text.SimpleDateFormat(\"yyyy-MM-dd\").format(sourceVal))"),
        new ExpectedResult("java.sql.Date", "java.lang.String[]", null),
        new ExpectedResult("java.sql.Date", "com.example.UserClass1", null),
        new ExpectedResult("java.sql.Date", "com.example.UserClass1[]", null),
        new ExpectedResult("java.sql.Date", "com.example.UserClass2", null),
        new ExpectedResult("java.sql.Date", "com.example.UserClass2[]", null),
        new ExpectedResult("java.sql.Date", "java.math.BigInteger", null),
        new ExpectedResult("java.sql.Date", "java.math.BigInteger[]", null),
        new ExpectedResult("java.sql.Date", "java.math.BigDecimal", null),
        new ExpectedResult("java.sql.Date", "java.math.BigDecimal[]", null),
        new ExpectedResult("java.sql.Date[]", "int", null),
        new ExpectedResult("java.sql.Date[]", "int[]", null),
        new ExpectedResult("java.sql.Date[]", "long", null),
        new ExpectedResult("java.sql.Date[]", "long[]", null),
        new ExpectedResult("java.sql.Date[]", "double", null),
        new ExpectedResult("java.sql.Date[]", "double[]", null),
        new ExpectedResult("java.sql.Date[]", "float", null),
        new ExpectedResult("java.sql.Date[]", "float[]", null),
        new ExpectedResult("java.sql.Date[]", "boolean", null),
        new ExpectedResult("java.sql.Date[]", "boolean[]", null),
        new ExpectedResult("java.sql.Date[]", "java.lang.Integer", null),
        new ExpectedResult("java.sql.Date[]", "java.lang.Integer[]", null),
        new ExpectedResult("java.sql.Date[]", "java.lang.Long", null),
        new ExpectedResult("java.sql.Date[]", "java.lang.Long[]", null),
        new ExpectedResult("java.sql.Date[]", "java.lang.Double", null),
        new ExpectedResult("java.sql.Date[]", "java.lang.Double[]", null),
        new ExpectedResult("java.sql.Date[]", "java.lang.Float", null),
        new ExpectedResult("java.sql.Date[]", "java.lang.Float[]", null),
        new ExpectedResult("java.sql.Date[]", "java.lang.Boolean", null),
        new ExpectedResult("java.sql.Date[]", "java.lang.Boolean[]", null),
        new ExpectedResult("java.sql.Date[]", "java.util.Date", null),
        new ExpectedResult("java.sql.Date[]", "java.util.Date[]", null),
        new ExpectedResult("java.sql.Date[]", "java.sql.Timestamp", null),
        new ExpectedResult("java.sql.Date[]", "java.sql.Timestamp[]", null),
        new ExpectedResult("java.sql.Date[]", "java.sql.Time", null),
        new ExpectedResult("java.sql.Date[]", "java.sql.Time[]", null),
        new ExpectedResult("java.sql.Date[]", "java.sql.Date", null),
        new ExpectedResult("java.sql.Date[]", "java.sql.Date[]", "sourceVal"),
        new ExpectedResult("java.sql.Date[]", "java.lang.String", null),
        new ExpectedResult("java.sql.Date[]", "java.lang.String[]", null),
        new ExpectedResult("java.sql.Date[]", "com.example.UserClass1", null),
        new ExpectedResult("java.sql.Date[]", "com.example.UserClass1[]", null),
        new ExpectedResult("java.sql.Date[]", "com.example.UserClass2", null),
        new ExpectedResult("java.sql.Date[]", "com.example.UserClass2[]", null),
        new ExpectedResult("java.sql.Date[]", "java.math.BigInteger", null),
        new ExpectedResult("java.sql.Date[]", "java.math.BigInteger[]", null),
        new ExpectedResult("java.sql.Date[]", "java.math.BigDecimal", null),
        new ExpectedResult("java.sql.Date[]", "java.math.BigDecimal[]", null),
        new ExpectedResult("java.lang.String", "int", "(sourceVal == null ? 0 : Integer.valueOf(sourceVal).intValue())"),
        new ExpectedResult("java.lang.String", "int[]", null),
        new ExpectedResult("java.lang.String", "long", "(sourceVal == null ? 0 : Long.valueOf(sourceVal).longValue())"),
        new ExpectedResult("java.lang.String", "long[]", null),
        new ExpectedResult("java.lang.String", "double", "(sourceVal == null ? 0.0 : Double.valueOf(sourceVal).doubleValue())"),
        new ExpectedResult("java.lang.String", "double[]", null),
        new ExpectedResult("java.lang.String", "float", "(sourceVal == null ? 0.0f : Float.valueOf(sourceVal).floatValue())"),
        new ExpectedResult("java.lang.String", "float[]", null),
        new ExpectedResult("java.lang.String", "boolean", "(sourceVal == null ? false : Boolean.valueOf(sourceVal).booleanValue())"),
        new ExpectedResult("java.lang.String", "boolean[]", null),
        new ExpectedResult("java.lang.String", "java.lang.Integer", "(sourceVal == null ? null : Integer.valueOf(sourceVal))"),
        new ExpectedResult("java.lang.String", "java.lang.Integer[]", null),
        new ExpectedResult("java.lang.String", "java.lang.Long", "(sourceVal == null ? null : Long.valueOf(sourceVal))"),
        new ExpectedResult("java.lang.String", "java.lang.Long[]", null),
        new ExpectedResult("java.lang.String", "java.lang.Double", "(sourceVal == null ? null : Double.valueOf(sourceVal))"),
        new ExpectedResult("java.lang.String", "java.lang.Double[]", null),
        new ExpectedResult("java.lang.String", "java.lang.Float", "(sourceVal == null ? null : Float.valueOf(sourceVal))"),
        new ExpectedResult("java.lang.String", "java.lang.Float[]", null),
        new ExpectedResult("java.lang.String", "java.lang.Boolean", "(sourceVal == null ? null : Boolean.valueOf(sourceVal))"),
        new ExpectedResult("java.lang.String", "java.lang.Boolean[]", null),
        new ExpectedResult("java.lang.String", "java.util.Date", "(sourceVal == null ? null : new java.text.SimpleDateFormat(\"yyyy-MM-dd HH:mm:ssZ\").parse(sourceVal))"),
        new ExpectedResult("java.lang.String", "java.util.Date[]", null),
        new ExpectedResult("java.lang.String", "java.sql.Timestamp", "(sourceVal == null ? null : new java.sql.Timestamp(new java.text.SimpleDateFormat(\"yyyy-MM-dd HH:mm:ssZ\").parse(sourceVal).getTime()))"),
        new ExpectedResult("java.lang.String", "java.sql.Timestamp[]", null),
        new ExpectedResult("java.lang.String", "java.sql.Time", "(sourceVal == null ? null : new java.sql.Time(new java.text.SimpleDateFormat(\"HH:mm:ssZ\").parse(sourceVal).getTime()))"),
        new ExpectedResult("java.lang.String", "java.sql.Time[]", null),
        new ExpectedResult("java.lang.String", "java.sql.Date", "(sourceVal == null ? null : new java.sql.Date(new java.text.SimpleDateFormat(\"yyyy-MM-dd\").parse(sourceVal).getTime()))"),
        new ExpectedResult("java.lang.String", "java.sql.Date[]", null),
        new ExpectedResult("java.lang.String", "java.lang.String", "sourceVal"),
        new ExpectedResult("java.lang.String", "java.lang.String[]", null),
        new ExpectedResult("java.lang.String", "com.example.UserClass1", null),
        new ExpectedResult("java.lang.String", "com.example.UserClass1[]", null),
        new ExpectedResult("java.lang.String", "com.example.UserClass2", null),
        new ExpectedResult("java.lang.String", "com.example.UserClass2[]", null),
        new ExpectedResult("java.lang.String", "java.math.BigInteger", "new java.math.BigInteger(sourceVal)"),
        new ExpectedResult("java.lang.String", "java.math.BigInteger[]", null),
        new ExpectedResult("java.lang.String", "java.math.BigDecimal", "new java.math.BigDecimal(sourceVal)"),
        new ExpectedResult("java.lang.String", "java.math.BigDecimal[]", null),
        new ExpectedResult("java.lang.String", "java.lang.Character", "(sourceVal == null || sourceVal.length() == 0 ? null : java.lang.Character.valueOf(sourceVal.charAt(0)))"),
        new ExpectedResult("java.lang.String[]", "int", null),
        new ExpectedResult("java.lang.String[]", "int[]", null),
        new ExpectedResult("java.lang.String[]", "long", null),
        new ExpectedResult("java.lang.String[]", "long[]", null),
        new ExpectedResult("java.lang.String[]", "double", null),
        new ExpectedResult("java.lang.String[]", "double[]", null),
        new ExpectedResult("java.lang.String[]", "float", null),
        new ExpectedResult("java.lang.String[]", "float[]", null),
        new ExpectedResult("java.lang.String[]", "boolean", null),
        new ExpectedResult("java.lang.String[]", "boolean[]", null),
        new ExpectedResult("java.lang.String[]", "java.lang.Integer", null),
        new ExpectedResult("java.lang.String[]", "java.lang.Integer[]", null),
        new ExpectedResult("java.lang.String[]", "java.lang.Long", null),
        new ExpectedResult("java.lang.String[]", "java.lang.Long[]", null),
        new ExpectedResult("java.lang.String[]", "java.lang.Double", null),
        new ExpectedResult("java.lang.String[]", "java.lang.Double[]", null),
        new ExpectedResult("java.lang.String[]", "java.lang.Float", null),
        new ExpectedResult("java.lang.String[]", "java.lang.Float[]", null),
        new ExpectedResult("java.lang.String[]", "java.lang.Boolean", null),
        new ExpectedResult("java.lang.String[]", "java.lang.Boolean[]", null),
        new ExpectedResult("java.lang.String[]", "java.util.Date", null),
        new ExpectedResult("java.lang.String[]", "java.util.Date[]", null),
        new ExpectedResult("java.lang.String[]", "java.sql.Timestamp", null),
        new ExpectedResult("java.lang.String[]", "java.sql.Timestamp[]", null),
        new ExpectedResult("java.lang.String[]", "java.sql.Time", null),
        new ExpectedResult("java.lang.String[]", "java.sql.Time[]", null),
        new ExpectedResult("java.lang.String[]", "java.sql.Date", null),
        new ExpectedResult("java.lang.String[]", "java.sql.Date[]", null),
        new ExpectedResult("java.lang.String[]", "java.lang.String", null),
        new ExpectedResult("java.lang.String[]", "java.lang.String[]", "sourceVal"),
        new ExpectedResult("java.lang.String[]", "com.example.UserClass1", null),
        new ExpectedResult("java.lang.String[]", "com.example.UserClass1[]", null),
        new ExpectedResult("java.lang.String[]", "com.example.UserClass2", null),
        new ExpectedResult("java.lang.String[]", "com.example.UserClass2[]", null),
        new ExpectedResult("java.lang.String[]", "java.math.BigInteger", null),
        new ExpectedResult("java.lang.String[]", "java.math.BigInteger[]", null),
        new ExpectedResult("java.lang.String[]", "java.math.BigDecimal", null),
        new ExpectedResult("java.lang.String[]", "java.math.BigDecimal[]", null),
        new ExpectedResult("com.example.UserClass1", "int", null),
        new ExpectedResult("com.example.UserClass1", "int[]", null),
        new ExpectedResult("com.example.UserClass1", "long", null),
        new ExpectedResult("com.example.UserClass1", "long[]", null),
        new ExpectedResult("com.example.UserClass1", "double", null),
        new ExpectedResult("com.example.UserClass1", "double[]", null),
        new ExpectedResult("com.example.UserClass1", "float", null),
        new ExpectedResult("com.example.UserClass1", "float[]", null),
        new ExpectedResult("com.example.UserClass1", "boolean", null),
        new ExpectedResult("com.example.UserClass1", "boolean[]", null),
        new ExpectedResult("com.example.UserClass1", "java.lang.Integer", null),
        new ExpectedResult("com.example.UserClass1", "java.lang.Integer[]", null),
        new ExpectedResult("com.example.UserClass1", "java.lang.Long", null),
        new ExpectedResult("com.example.UserClass1", "java.lang.Long[]", null),
        new ExpectedResult("com.example.UserClass1", "java.lang.Double", null),
        new ExpectedResult("com.example.UserClass1", "java.lang.Double[]", null),
        new ExpectedResult("com.example.UserClass1", "java.lang.Float", null),
        new ExpectedResult("com.example.UserClass1", "java.lang.Float[]", null),
        new ExpectedResult("com.example.UserClass1", "java.lang.Boolean", null),
        new ExpectedResult("com.example.UserClass1", "java.lang.Boolean[]", null),
        new ExpectedResult("com.example.UserClass1", "java.util.Date", null),
        new ExpectedResult("com.example.UserClass1", "java.util.Date[]", null),
        new ExpectedResult("com.example.UserClass1", "java.sql.Timestamp", null),
        new ExpectedResult("com.example.UserClass1", "java.sql.Timestamp[]", null),
        new ExpectedResult("com.example.UserClass1", "java.sql.Time", null),
        new ExpectedResult("com.example.UserClass1", "java.sql.Time[]", null),
        new ExpectedResult("com.example.UserClass1", "java.sql.Date", null),
        new ExpectedResult("com.example.UserClass1", "java.sql.Date[]", null),
        new ExpectedResult("com.example.UserClass1", "java.lang.String", null),
        new ExpectedResult("com.example.UserClass1", "java.lang.String[]", null),
        new ExpectedResult("com.example.UserClass1", "com.example.UserClass1", "sourceVal"),
        new ExpectedResult("com.example.UserClass1", "com.example.UserClass1[]", null),
        new ExpectedResult("com.example.UserClass1", "com.example.UserClass2", null),
        new ExpectedResult("com.example.UserClass1", "com.example.UserClass2[]", null),
        new ExpectedResult("com.example.UserClass1", "java.math.BigInteger", null),
        new ExpectedResult("com.example.UserClass1", "java.math.BigInteger[]", null),
        new ExpectedResult("com.example.UserClass1", "java.math.BigDecimal", null),
        new ExpectedResult("com.example.UserClass1", "java.math.BigDecimal[]", null),
        new ExpectedResult("com.example.UserClass1[]", "int", null),
        new ExpectedResult("com.example.UserClass1[]", "int[]", null),
        new ExpectedResult("com.example.UserClass1[]", "long", null),
        new ExpectedResult("com.example.UserClass1[]", "long[]", null),
        new ExpectedResult("com.example.UserClass1[]", "double", null),
        new ExpectedResult("com.example.UserClass1[]", "double[]", null),
        new ExpectedResult("com.example.UserClass1[]", "float", null),
        new ExpectedResult("com.example.UserClass1[]", "float[]", null),
        new ExpectedResult("com.example.UserClass1[]", "boolean", null),
        new ExpectedResult("com.example.UserClass1[]", "boolean[]", null),
        new ExpectedResult("com.example.UserClass1[]", "java.lang.Integer", null),
        new ExpectedResult("com.example.UserClass1[]", "java.lang.Integer[]", null),
        new ExpectedResult("com.example.UserClass1[]", "java.lang.Long", null),
        new ExpectedResult("com.example.UserClass1[]", "java.lang.Long[]", null),
        new ExpectedResult("com.example.UserClass1[]", "java.lang.Double", null),
        new ExpectedResult("com.example.UserClass1[]", "java.lang.Double[]", null),
        new ExpectedResult("com.example.UserClass1[]", "java.lang.Float", null),
        new ExpectedResult("com.example.UserClass1[]", "java.lang.Float[]", null),
        new ExpectedResult("com.example.UserClass1[]", "java.lang.Boolean", null),
        new ExpectedResult("com.example.UserClass1[]", "java.lang.Boolean[]", null),
        new ExpectedResult("com.example.UserClass1[]", "java.util.Date", null),
        new ExpectedResult("com.example.UserClass1[]", "java.util.Date[]", null),
        new ExpectedResult("com.example.UserClass1[]", "java.sql.Timestamp", null),
        new ExpectedResult("com.example.UserClass1[]", "java.sql.Timestamp[]", null),
        new ExpectedResult("com.example.UserClass1[]", "java.sql.Time", null),
        new ExpectedResult("com.example.UserClass1[]", "java.sql.Time[]", null),
        new ExpectedResult("com.example.UserClass1[]", "java.sql.Date", null),
        new ExpectedResult("com.example.UserClass1[]", "java.sql.Date[]", null),
        new ExpectedResult("com.example.UserClass1[]", "java.lang.String", null),
        new ExpectedResult("com.example.UserClass1[]", "java.lang.String[]", null),
        new ExpectedResult("com.example.UserClass1[]", "com.example.UserClass1", null),
        new ExpectedResult("com.example.UserClass1[]", "com.example.UserClass1[]", "sourceVal"),
        new ExpectedResult("com.example.UserClass1[]", "com.example.UserClass2", null),
        new ExpectedResult("com.example.UserClass1[]", "com.example.UserClass2[]", null),
        new ExpectedResult("com.example.UserClass1[]", "java.math.BigInteger", null),
        new ExpectedResult("com.example.UserClass1[]", "java.math.BigInteger[]", null),
        new ExpectedResult("com.example.UserClass1[]", "java.math.BigDecimal", null),
        new ExpectedResult("com.example.UserClass1[]", "java.math.BigDecimal[]", null),
        new ExpectedResult("com.example.UserClass2", "int", null),
        new ExpectedResult("com.example.UserClass2", "int[]", null),
        new ExpectedResult("com.example.UserClass2", "long", null),
        new ExpectedResult("com.example.UserClass2", "long[]", null),
        new ExpectedResult("com.example.UserClass2", "double", null),
        new ExpectedResult("com.example.UserClass2", "double[]", null),
        new ExpectedResult("com.example.UserClass2", "float", null),
        new ExpectedResult("com.example.UserClass2", "float[]", null),
        new ExpectedResult("com.example.UserClass2", "boolean", null),
        new ExpectedResult("com.example.UserClass2", "boolean[]", null),
        new ExpectedResult("com.example.UserClass2", "java.lang.Integer", null),
        new ExpectedResult("com.example.UserClass2", "java.lang.Integer[]", null),
        new ExpectedResult("com.example.UserClass2", "java.lang.Long", null),
        new ExpectedResult("com.example.UserClass2", "java.lang.Long[]", null),
        new ExpectedResult("com.example.UserClass2", "java.lang.Double", null),
        new ExpectedResult("com.example.UserClass2", "java.lang.Double[]", null),
        new ExpectedResult("com.example.UserClass2", "java.lang.Float", null),
        new ExpectedResult("com.example.UserClass2", "java.lang.Float[]", null),
        new ExpectedResult("com.example.UserClass2", "java.lang.Boolean", null),
        new ExpectedResult("com.example.UserClass2", "java.lang.Boolean[]", null),
        new ExpectedResult("com.example.UserClass2", "java.util.Date", null),
        new ExpectedResult("com.example.UserClass2", "java.util.Date[]", null),
        new ExpectedResult("com.example.UserClass2", "java.sql.Timestamp", null),
        new ExpectedResult("com.example.UserClass2", "java.sql.Timestamp[]", null),
        new ExpectedResult("com.example.UserClass2", "java.sql.Time", null),
        new ExpectedResult("com.example.UserClass2", "java.sql.Time[]", null),
        new ExpectedResult("com.example.UserClass2", "java.sql.Date", null),
        new ExpectedResult("com.example.UserClass2", "java.sql.Date[]", null),
        new ExpectedResult("com.example.UserClass2", "java.lang.String", null),
        new ExpectedResult("com.example.UserClass2", "java.lang.String[]", null),
        new ExpectedResult("com.example.UserClass2", "com.example.UserClass1", null),
        new ExpectedResult("com.example.UserClass2", "com.example.UserClass1[]", null),
        new ExpectedResult("com.example.UserClass2", "com.example.UserClass2", "sourceVal"),
        new ExpectedResult("com.example.UserClass2", "com.example.UserClass2[]", null),
        new ExpectedResult("com.example.UserClass2", "java.math.BigInteger", null),
        new ExpectedResult("com.example.UserClass2", "java.math.BigInteger[]", null),
        new ExpectedResult("com.example.UserClass2", "java.math.BigDecimal", null),
        new ExpectedResult("com.example.UserClass2", "java.math.BigDecimal[]", null),
        new ExpectedResult("com.example.UserClass2[]", "int", null),
        new ExpectedResult("com.example.UserClass2[]", "int[]", null),
        new ExpectedResult("com.example.UserClass2[]", "long", null),
        new ExpectedResult("com.example.UserClass2[]", "long[]", null),
        new ExpectedResult("com.example.UserClass2[]", "double", null),
        new ExpectedResult("com.example.UserClass2[]", "double[]", null),
        new ExpectedResult("com.example.UserClass2[]", "float", null),
        new ExpectedResult("com.example.UserClass2[]", "float[]", null),
        new ExpectedResult("com.example.UserClass2[]", "boolean", null),
        new ExpectedResult("com.example.UserClass2[]", "boolean[]", null),
        new ExpectedResult("com.example.UserClass2[]", "java.lang.Integer", null),
        new ExpectedResult("com.example.UserClass2[]", "java.lang.Integer[]", null),
        new ExpectedResult("com.example.UserClass2[]", "java.lang.Long", null),
        new ExpectedResult("com.example.UserClass2[]", "java.lang.Long[]", null),
        new ExpectedResult("com.example.UserClass2[]", "java.lang.Double", null),
        new ExpectedResult("com.example.UserClass2[]", "java.lang.Double[]", null),
        new ExpectedResult("com.example.UserClass2[]", "java.lang.Float", null),
        new ExpectedResult("com.example.UserClass2[]", "java.lang.Float[]", null),
        new ExpectedResult("com.example.UserClass2[]", "java.lang.Boolean", null),
        new ExpectedResult("com.example.UserClass2[]", "java.lang.Boolean[]", null),
        new ExpectedResult("com.example.UserClass2[]", "java.util.Date", null),
        new ExpectedResult("com.example.UserClass2[]", "java.util.Date[]", null),
        new ExpectedResult("com.example.UserClass2[]", "java.sql.Timestamp", null),
        new ExpectedResult("com.example.UserClass2[]", "java.sql.Timestamp[]", null),
        new ExpectedResult("com.example.UserClass2[]", "java.sql.Time", null),
        new ExpectedResult("com.example.UserClass2[]", "java.sql.Time[]", null),
        new ExpectedResult("com.example.UserClass2[]", "java.sql.Date", null),
        new ExpectedResult("com.example.UserClass2[]", "java.sql.Date[]", null),
        new ExpectedResult("com.example.UserClass2[]", "java.lang.String", null),
        new ExpectedResult("com.example.UserClass2[]", "java.lang.String[]", null),
        new ExpectedResult("com.example.UserClass2[]", "com.example.UserClass1", null),
        new ExpectedResult("com.example.UserClass2[]", "com.example.UserClass1[]", null),
        new ExpectedResult("com.example.UserClass2[]", "com.example.UserClass2", null),
        new ExpectedResult("com.example.UserClass2[]", "com.example.UserClass2[]", "sourceVal"),
        new ExpectedResult("com.example.UserClass2[]", "java.math.BigInteger", null),
        new ExpectedResult("com.example.UserClass2[]", "java.math.BigInteger[]", null),
        new ExpectedResult("com.example.UserClass2[]", "java.math.BigDecimal", null),
        new ExpectedResult("com.example.UserClass2[]", "java.math.BigDecimal[]", null),
        new ExpectedResult("java.math.BigInteger", "int", "(sourceVal == null ? 0 : sourceVal.intValue())"),
        new ExpectedResult("java.math.BigInteger", "int[]", null),
        new ExpectedResult("java.math.BigInteger", "long", "(sourceVal == null ? 0 : sourceVal.longValue())"),
        new ExpectedResult("java.math.BigInteger", "long[]", null),
        new ExpectedResult("java.math.BigInteger", "double", "(sourceVal == null ? 0.0 : sourceVal.doubleValue())"),
        new ExpectedResult("java.math.BigInteger", "double[]", null),
        new ExpectedResult("java.math.BigInteger", "float", "(sourceVal == null ? 0.0f : sourceVal.floatValue())"),
        new ExpectedResult("java.math.BigInteger", "float[]", null),
        new ExpectedResult("java.math.BigInteger", "boolean", null),
        new ExpectedResult("java.math.BigInteger", "boolean[]", null),
        new ExpectedResult("java.math.BigInteger", "java.lang.Integer", "(sourceVal == null ? null : new java.lang.Integer(sourceVal.intValue()))"),
        new ExpectedResult("java.math.BigInteger", "java.lang.Integer[]", null),
        new ExpectedResult("java.math.BigInteger", "java.lang.Long", "(sourceVal == null ? null : new java.lang.Long(sourceVal.longValue()))"),
        new ExpectedResult("java.math.BigInteger", "java.lang.Long[]", null),
        new ExpectedResult("java.math.BigInteger", "java.lang.Double", "new java.lang.Double((sourceVal == null ? 0.0 : sourceVal.doubleValue()))"),
        new ExpectedResult("java.math.BigInteger", "java.lang.Double[]", null),
        new ExpectedResult("java.math.BigInteger", "java.lang.Float", "new java.lang.Float((sourceVal == null ? 0.0f : sourceVal.floatValue()))"),
        new ExpectedResult("java.math.BigInteger", "java.lang.Float[]", null),
        new ExpectedResult("java.math.BigInteger", "java.lang.Boolean", null),
        new ExpectedResult("java.math.BigInteger", "java.lang.Boolean[]", null),
        new ExpectedResult("java.math.BigInteger", "java.util.Date", null),
        new ExpectedResult("java.math.BigInteger", "java.util.Date[]", null),
        new ExpectedResult("java.math.BigInteger", "java.sql.Timestamp", null),
        new ExpectedResult("java.math.BigInteger", "java.sql.Timestamp[]", null),
        new ExpectedResult("java.math.BigInteger", "java.sql.Time", null),
        new ExpectedResult("java.math.BigInteger", "java.sql.Time[]", null),
        new ExpectedResult("java.math.BigInteger", "java.sql.Date", null),
        new ExpectedResult("java.math.BigInteger", "java.sql.Date[]", null),
        new ExpectedResult("java.math.BigInteger", "java.lang.String", "(sourceVal == null ? null : sourceVal.toString())"),
        new ExpectedResult("java.math.BigInteger", "java.lang.String[]", null),
        new ExpectedResult("java.math.BigInteger", "com.example.UserClass1", null),
        new ExpectedResult("java.math.BigInteger", "com.example.UserClass1[]", null),
        new ExpectedResult("java.math.BigInteger", "com.example.UserClass2", null),
        new ExpectedResult("java.math.BigInteger", "com.example.UserClass2[]", null),
        new ExpectedResult("java.math.BigInteger", "java.math.BigInteger", "sourceVal"),
        new ExpectedResult("java.math.BigInteger", "java.math.BigInteger[]", null),
        new ExpectedResult("java.math.BigInteger", "java.math.BigDecimal", "new java.math.BigDecimal(sourceVal)"),
        new ExpectedResult("java.math.BigInteger", "java.math.BigDecimal[]", null),
        new ExpectedResult("java.math.BigInteger[]", "int", null),
        new ExpectedResult("java.math.BigInteger[]", "int[]", null),
        new ExpectedResult("java.math.BigInteger[]", "long", null),
        new ExpectedResult("java.math.BigInteger[]", "long[]", null),
        new ExpectedResult("java.math.BigInteger[]", "double", null),
        new ExpectedResult("java.math.BigInteger[]", "double[]", null),
        new ExpectedResult("java.math.BigInteger[]", "float", null),
        new ExpectedResult("java.math.BigInteger[]", "float[]", null),
        new ExpectedResult("java.math.BigInteger[]", "boolean", null),
        new ExpectedResult("java.math.BigInteger[]", "boolean[]", null),
        new ExpectedResult("java.math.BigInteger[]", "java.lang.Integer", null),
        new ExpectedResult("java.math.BigInteger[]", "java.lang.Integer[]", null),
        new ExpectedResult("java.math.BigInteger[]", "java.lang.Long", null),
        new ExpectedResult("java.math.BigInteger[]", "java.lang.Long[]", null),
        new ExpectedResult("java.math.BigInteger[]", "java.lang.Double", null),
        new ExpectedResult("java.math.BigInteger[]", "java.lang.Double[]", null),
        new ExpectedResult("java.math.BigInteger[]", "java.lang.Float", null),
        new ExpectedResult("java.math.BigInteger[]", "java.lang.Float[]", null),
        new ExpectedResult("java.math.BigInteger[]", "java.lang.Boolean", null),
        new ExpectedResult("java.math.BigInteger[]", "java.lang.Boolean[]", null),
        new ExpectedResult("java.math.BigInteger[]", "java.util.Date", null),
        new ExpectedResult("java.math.BigInteger[]", "java.util.Date[]", null),
        new ExpectedResult("java.math.BigInteger[]", "java.sql.Timestamp", null),
        new ExpectedResult("java.math.BigInteger[]", "java.sql.Timestamp[]", null),
        new ExpectedResult("java.math.BigInteger[]", "java.sql.Time", null),
        new ExpectedResult("java.math.BigInteger[]", "java.sql.Time[]", null),
        new ExpectedResult("java.math.BigInteger[]", "java.sql.Date", null),
        new ExpectedResult("java.math.BigInteger[]", "java.sql.Date[]", null),
        new ExpectedResult("java.math.BigInteger[]", "java.lang.String", null),
        new ExpectedResult("java.math.BigInteger[]", "java.lang.String[]", null),
        new ExpectedResult("java.math.BigInteger[]", "com.example.UserClass1", null),
        new ExpectedResult("java.math.BigInteger[]", "com.example.UserClass1[]", null),
        new ExpectedResult("java.math.BigInteger[]", "com.example.UserClass2", null),
        new ExpectedResult("java.math.BigInteger[]", "com.example.UserClass2[]", null),
        new ExpectedResult("java.math.BigInteger[]", "java.math.BigInteger", null),
        new ExpectedResult("java.math.BigInteger[]", "java.math.BigInteger[]", "sourceVal"),
        new ExpectedResult("java.math.BigInteger[]", "java.math.BigDecimal", null),
        new ExpectedResult("java.math.BigInteger[]", "java.math.BigDecimal[]", null),
        new ExpectedResult("java.math.BigDecimal", "int", "(sourceVal == null ? 0 : sourceVal.intValue())"),
        new ExpectedResult("java.math.BigDecimal", "int[]", null),
        new ExpectedResult("java.math.BigDecimal", "long", "(sourceVal == null ? 0 : sourceVal.longValue())"),
        new ExpectedResult("java.math.BigDecimal", "long[]", null),
        new ExpectedResult("java.math.BigDecimal", "double", "(sourceVal == null ? 0.0 : sourceVal.doubleValue())"),
        new ExpectedResult("java.math.BigDecimal", "double[]", null),
        new ExpectedResult("java.math.BigDecimal", "float", "(sourceVal == null ? 0.0f : sourceVal.floatValue())"),
        new ExpectedResult("java.math.BigDecimal", "float[]", null),
        new ExpectedResult("java.math.BigDecimal", "boolean", null),
        new ExpectedResult("java.math.BigDecimal", "boolean[]", null),
        new ExpectedResult("java.math.BigDecimal", "java.lang.Integer", "(sourceVal == null ? null : new java.lang.Integer(sourceVal.intValue()))"),
        new ExpectedResult("java.math.BigDecimal", "java.lang.Integer[]", null),
        new ExpectedResult("java.math.BigDecimal", "java.lang.Long", "(sourceVal == null ? null : new java.lang.Long(sourceVal.longValue()))"),
        new ExpectedResult("java.math.BigDecimal", "java.lang.Long[]", null),
        new ExpectedResult("java.math.BigDecimal", "java.lang.Double", "new java.lang.Double((sourceVal == null ? 0.0 : sourceVal.doubleValue()))"),
        new ExpectedResult("java.math.BigDecimal", "java.lang.Double[]", null),
        new ExpectedResult("java.math.BigDecimal", "java.lang.Float", "new java.lang.Float((sourceVal == null ? 0.0f : sourceVal.floatValue()))"),
        new ExpectedResult("java.math.BigDecimal", "java.lang.Float[]", null),
        new ExpectedResult("java.math.BigDecimal", "java.lang.Boolean", null),
        new ExpectedResult("java.math.BigDecimal", "java.lang.Boolean[]", null),
        new ExpectedResult("java.math.BigDecimal", "java.util.Date", null),
        new ExpectedResult("java.math.BigDecimal", "java.util.Date[]", null),
        new ExpectedResult("java.math.BigDecimal", "java.sql.Timestamp", null),
        new ExpectedResult("java.math.BigDecimal", "java.sql.Timestamp[]", null),
        new ExpectedResult("java.math.BigDecimal", "java.sql.Time", null),
        new ExpectedResult("java.math.BigDecimal", "java.sql.Time[]", null),
        new ExpectedResult("java.math.BigDecimal", "java.sql.Date", null),
        new ExpectedResult("java.math.BigDecimal", "java.sql.Date[]", null),
        new ExpectedResult("java.math.BigDecimal", "java.lang.String", "(sourceVal == null ? null : sourceVal.toString())"),
        new ExpectedResult("java.math.BigDecimal", "java.lang.String[]", null),
        new ExpectedResult("java.math.BigDecimal", "com.example.UserClass1", null),
        new ExpectedResult("java.math.BigDecimal", "com.example.UserClass1[]", null),
        new ExpectedResult("java.math.BigDecimal", "com.example.UserClass2", null),
        new ExpectedResult("java.math.BigDecimal", "com.example.UserClass2[]", null),
        new ExpectedResult("java.math.BigDecimal", "java.math.BigInteger", "(sourceVal == null ? null : sourceVal.toBigInteger())"),
        new ExpectedResult("java.math.BigDecimal", "java.math.BigInteger[]", null),
        new ExpectedResult("java.math.BigDecimal", "java.math.BigDecimal", "sourceVal"),
        new ExpectedResult("java.math.BigDecimal", "java.math.BigDecimal[]", null),
        new ExpectedResult("java.math.BigDecimal[]", "int", null),
        new ExpectedResult("java.math.BigDecimal[]", "int[]", null),
        new ExpectedResult("java.math.BigDecimal[]", "long", null),
        new ExpectedResult("java.math.BigDecimal[]", "long[]", null),
        new ExpectedResult("java.math.BigDecimal[]", "double", null),
        new ExpectedResult("java.math.BigDecimal[]", "double[]", null),
        new ExpectedResult("java.math.BigDecimal[]", "float", null),
        new ExpectedResult("java.math.BigDecimal[]", "float[]", null),
        new ExpectedResult("java.math.BigDecimal[]", "boolean", null),
        new ExpectedResult("java.math.BigDecimal[]", "boolean[]", null),
        new ExpectedResult("java.math.BigDecimal[]", "java.lang.Integer", null),
        new ExpectedResult("java.math.BigDecimal[]", "java.lang.Integer[]", null),
        new ExpectedResult("java.math.BigDecimal[]", "java.lang.Long", null),
        new ExpectedResult("java.math.BigDecimal[]", "java.lang.Long[]", null),
        new ExpectedResult("java.math.BigDecimal[]", "java.lang.Double", null),
        new ExpectedResult("java.math.BigDecimal[]", "java.lang.Double[]", null),
        new ExpectedResult("java.math.BigDecimal[]", "java.lang.Float", null),
        new ExpectedResult("java.math.BigDecimal[]", "java.lang.Float[]", null),
        new ExpectedResult("java.math.BigDecimal[]", "java.lang.Boolean", null),
        new ExpectedResult("java.math.BigDecimal[]", "java.lang.Boolean[]", null),
        new ExpectedResult("java.math.BigDecimal[]", "java.util.Date", null),
        new ExpectedResult("java.math.BigDecimal[]", "java.util.Date[]", null),
        new ExpectedResult("java.math.BigDecimal[]", "java.sql.Timestamp", null),
        new ExpectedResult("java.math.BigDecimal[]", "java.sql.Timestamp[]", null),
        new ExpectedResult("java.math.BigDecimal[]", "java.sql.Time", null),
        new ExpectedResult("java.math.BigDecimal[]", "java.sql.Time[]", null),
        new ExpectedResult("java.math.BigDecimal[]", "java.sql.Date", null),
        new ExpectedResult("java.math.BigDecimal[]", "java.sql.Date[]", null),
        new ExpectedResult("java.math.BigDecimal[]", "java.lang.String", null),
        new ExpectedResult("java.math.BigDecimal[]", "java.lang.String[]", null),
        new ExpectedResult("java.math.BigDecimal[]", "com.example.UserClass1", null),
        new ExpectedResult("java.math.BigDecimal[]", "com.example.UserClass1[]", null),
        new ExpectedResult("java.math.BigDecimal[]", "com.example.UserClass2", null),
        new ExpectedResult("java.math.BigDecimal[]", "com.example.UserClass2[]", null),
        new ExpectedResult("java.math.BigDecimal[]", "java.math.BigInteger", null),
        new ExpectedResult("java.math.BigDecimal[]", "java.math.BigInteger[]", null),
        new ExpectedResult("java.math.BigDecimal[]", "java.math.BigDecimal", null),
        new ExpectedResult("java.math.BigDecimal[]", "java.math.BigDecimal[]", "sourceVal"),
        new ExpectedResult("java.lang.Object", "java.lang.String", "sourceVal == null ? null : sourceVal.toString()"),
        new ExpectedResult("java.lang.Object", "java.lang.Integer", "sourceVal == null ? null : sourceVal.toString()"),
        new ExpectedResult("java.lang.Object", "java.lang.Long", "sourceVal == null ? null : sourceVal.toString()"),
        new ExpectedResult("java.lang.Object", "java.lang.Float", "sourceVal == null ? null : sourceVal.toString()"),
        new ExpectedResult("java.lang.Object", "java.lang.Double", "sourceVal == null ? null : sourceVal.toString()"),
        new ExpectedResult("java.lang.Object", "java.lang.Character", "(sourceVal == null || sourceVal.toString().length() == 0 ? null : java.lang.Character.valueOf(sourceVal.toString().charAr(0)))"),
        new ExpectedResult("java.lang.String", "java.lang.Object", "sourceVal"),
        new ExpectedResult("java.lang.Integer", "java.lang.Object", "sourceVal"),
        new ExpectedResult("java.lang.Long", "java.lang.Object", "sourceVal"),
        new ExpectedResult("java.lang.Float", "java.lang.Object", "sourceVal"),
        new ExpectedResult("java.lang.Double", "java.lang.Object", "sourceVal"),
        new ExpectedResult("java.lang.Character", "java.lang.Object", "sourceVal"),
        new ExpectedResult("java.lang.Character", "char", "(sourceVal == null ? 0 : sourceVal.charValue())"),
        new ExpectedResult("char", "java.lang.Character", "java.lang.Character.valueOf(sourceVal)"),
    };

    /**
     *
     */
    @Test
    public void testTypeConversion()
    {
        final JavaTypeConverter converter = new JavaTypeConverter();
        for (ExpectedResult anExpected : expected)
        {
            final String result = converter.typeConvert(anExpected.fromType, "sourceVal", anExpected.toType);
            assertEquals("Converting " + anExpected.fromType + " to " +
                    anExpected.toType, anExpected.expected, result);
        }
    }

    /**
     *
     */
    @Test
    public void testTypeConversionWithIgnore()
    {
        final JavaTypeConverter converter = new JavaTypeConverter();
        converter.setJavaTypeConversionIgnoreList("java.util.Date, java.sql.Timestamp");

        for (ExpectedResult anExpected : expected)
        {
            final String result = converter.typeConvert(anExpected.fromType, "sourceVal", anExpected.toType);
            if ("java.util.Date".equals(anExpected.fromType) ||
                    "java.sql.Timestamp".equals(anExpected.fromType) ||
                    "java.util.Date".equals(anExpected.toType) ||
                    "java.sql.Timestamp".equals(anExpected.toType))
            {
                assertNull("Converting " + anExpected.fromType + " to " + anExpected.toType +
                    " should have been null, was: " + result, result);
            }
            else
            {
                assertEquals("Converting " + anExpected.fromType + " to " + anExpected.toType,
                        anExpected.expected, result);
            }
        }
    }

    /**
     * This method generates the "expected" source array, so it can be cut and
     * pasted from the console output to this class, AFTER is has been examined
     * by the programmer for accuracy (and/or sent through the compiler with
     * code from genActualSource()).
     * @see #genActualSource()
     */
    public static void generateExpectedSource()
    {
        final String[] knownTypes =
        {
            "int", "long", "double", "float", "boolean",
            "java.lang.Integer", "java.lang.Long", "java.lang.Double", "java.lang.Float", "java.lang.Boolean",
            "java.util.Date", "java.sql.Timestamp", "java.sql.Time", "java.sql.Date",
            "java.lang.String", "com.example.UserClass1", "com.example.UserClass2",
            "java.math.BigInteger", "java.math.BigDecimal"
        };

        final String[] typeSuffix = { "", "[]" };

        final JavaTypeConverter converter = new JavaTypeConverter();

        boolean firstOut = false;
        for (int fromIndex = 0; fromIndex < knownTypes.length; fromIndex++)
        {
            for (int fromSuffix = 0; fromSuffix < typeSuffix.length; fromSuffix++ )
            {
                for (int toIndex = 0; toIndex < knownTypes.length; toIndex++)
                {
                   for (int toSuffix = 0; toSuffix < typeSuffix.length; toSuffix++)
                   {
                       if (!firstOut)
                       {
                           firstOut = true;
                       }
                       else
                       {
                           System.out.println(",");
                       }
                       System.out.print("        new ExpectedResult(\"");
                       System.out.print(knownTypes[fromIndex] + typeSuffix[fromSuffix]);
                       System.out.print("\", \"");
                       System.out.print(knownTypes[toIndex] + typeSuffix[toSuffix]);
                       System.out.print("\", ");
                       final String result = converter.typeConvert(knownTypes[fromIndex] + typeSuffix[fromSuffix], "sourceVal", knownTypes[toIndex] + typeSuffix[toSuffix]);
                       if (result != null)
                       {
                          System.out.print("\"");
                          System.out.print(result);
                          System.out.print("\"");
                       }
                       else
                       {
                          System.out.print("null");
                       }
                       System.out.print(")");
                   } // for toSuffix
                } // for toIndex
            } // for fromSuffix
        } // for fromIndex
    }

    /**
     * This method generates source code that uses the variations.  The source
     * can then be sent through a compiler and checked for correctness.
     */
    public static void genActualSource()
    {
        final String[] knownTypes =
        {
            "int", "long", "double", "float", "boolean",
            "java.lang.Integer", "java.lang.Long", "java.lang.Double", "java.lang.Float", "java.lang.Boolean",
            "java.util.Date", "java.sql.Timestamp", "java.sql.Time", "java.sql.Date",
            "java.lang.String", "java.math.BigInteger", "java.math.BigDecimal"
        };

        final String[] typeSuffix = { "", "[]" };

        final JavaTypeConverter converter = new JavaTypeConverter();

        int sourceCounter = 1;
        System.out.println("public void testConversionCode() throws java.text.ParseException {");
        for (int fromIndex = 0; fromIndex < knownTypes.length; fromIndex++)
        {
            for (int fromSuffix = 0; fromSuffix < typeSuffix.length; fromSuffix++ )
            {
                for (int toIndex = 0; toIndex < knownTypes.length; toIndex++)
                {
                    for (int toSuffix = 0; toSuffix < typeSuffix.length; toSuffix++)
                    {
                       final String sourceLabel = "source" + sourceCounter;
                       final String result = converter.typeConvert(knownTypes[fromIndex] + typeSuffix[fromSuffix], sourceLabel, knownTypes[toIndex] + typeSuffix[toSuffix]);
                       if (result != null)
                       {
                          System.out.print("     ");
                          System.out.print(knownTypes[fromIndex] + typeSuffix[fromSuffix]);
                          System.out.print(" ");
                          System.out.print(sourceLabel);
                          if ("[]".equals(typeSuffix[fromSuffix]))
                          {
                              System.out.print(" = new ");
                              System.out.print(knownTypes[fromIndex]);
                              System.out.println("[1];");
                          }
                          else if (knownTypes[fromIndex].indexOf('.') > 0)
                          {
                              System.out.println(" = null;");
                          }
                          else if ("boolean".equals(knownTypes[fromIndex]))
                          {
                              System.out.println(" = false;");
                          }
                          else
                          {
                              System.out.println(" = 0;");
                          }
                          System.out.print("     ");
                          System.out.print(knownTypes[toIndex] + typeSuffix[toSuffix]);
                          System.out.print(" dest" + sourceCounter);
                          System.out.print(" = ");
                          System.out.print(result);
                          System.out.println(";");
                          sourceCounter++;
                       }
                       else
                       {
                           System.out.print("     // No conversion from ");
                           System.out.print(knownTypes[fromIndex] + typeSuffix[fromSuffix]);
                           System.out.print(" to ");
                           System.out.println(knownTypes[toIndex] + typeSuffix[toSuffix]);
                       }
                       System.out.println();
                    }
                } // for toIndex
            } // for fromSuffix
        } // for fromIndex
        System.out.println("}");

    }

//    public static void main(String[] args) throws ParseException {
//        Uncomment to re-generated the "expected" if major mods are made
//        JavaTypeConverterTest.generateExpectedSource();

//        Uncomment to re-generate source code to put through compiler to check syntax
//        JavaTypeConverterTest.genActualSource();

//    }
}
